@@ -1,9 +1,7 @@
 # -*- coding: utf-8 -*-
 
-import sys
-
-import functools
 import logging
+import sys
 
 import click
 
@@ -60,7 +58,7 @@ class ClickHandler(logging.Handler):
             click.echo(msg, err=err)
         except (KeyboardInterrupt, SystemExit):
             raise
-        except:
+        except Exception:
             self.handleError(record)
 
 
@@ -68,52 +66,17 @@ _default_handler = ClickHandler()
 _default_handler.formatter = ColorFormatter()
 
 
+def _normalize_logger(logger):
+    if not isinstance(logger, logging.Logger):
+        logger = logging.getLogger(logger)
+    return logger
+
+
 def basic_config(logger=None):
     '''Set up the default handler (:py:class:`ClickHandler`) and formatter
     (:py:class:`ColorFormatter`) on the given logger.'''
-    if not isinstance(logger, logging.Logger):
-        logger = logging.getLogger(logger)
+    logger = _normalize_logger(logger)
     logger.handlers = [_default_handler]
     logger.propagate = False
 
     return logger
-
-
-def init(logger=None):
-    '''Set the application's logger and call :py:func:`basic_config` on it.'''
-    def decorator(f):
-        @functools.wraps(f)
-        def wrapper(*args, **kwargs):
-            m = _meta()
-            l = basic_config(logger=logger)
-            l.setLevel(m.get('level', DEFAULT_LEVEL))
-
-            if m.setdefault('logger', l) is not l:
-                raise RuntimeError('Only one main logger allowed.')
-
-            return f(*args, **kwargs)
-        return wrapper
-    return decorator
-
-
-def get_logger():
-    '''Get the application's logger.'''
-    return _meta().get('logger')
-
-
-def set_level(level):
-    '''Set the level for the application's logger.'''
-
-    if not isinstance(level, int):
-        raise ValueError('Must be constant from `logging`.')
-
-    logger = get_logger()
-    if logger is not None:
-        logger.setLevel(level)
-
-    _meta()['level'] = level
-
-
-def get_level():
-    '''Get the level for the application's logger.'''
-    return _meta().get('level', DEFAULT_LEVEL)
